"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var base_service_1 = require("./base.service");
var paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
var service_1 = require("../decorators/service");
var LogType;
(function (LogType) {
    LogType[LogType["Trace"] = 0] = "Trace";
    LogType[LogType["Debug"] = 1] = "Debug";
    LogType[LogType["Information"] = 2] = "Information";
    LogType[LogType["Warning"] = 3] = "Warning";
    LogType[LogType["Error"] = 4] = "Error";
    LogType[LogType["Critical"] = 5] = "Critical";
})(LogType = exports.LogType || (exports.LogType = {}));
var LoggingService = /** @class */ (function (_super) {
    tslib_1.__extends(LoggingService, _super);
    function LoggingService() {
        var _this = _super.call(this) || this;
        var message = "[{0}][{1}] - {3}{2}";
        _this.messages = new Array();
        _this.messages.push(message);
        _this.messages.push(message);
        _this.messages.push(message);
        _this.messages.push(message);
        _this.messages.push(message);
        _this.messages.push(message);
        _this.minimumLevel = LogType.Information;
        return _this;
    }
    LoggingService_1 = LoggingService;
    /**
     * Sets the custom message for a given log type.
     * There are some predefined content placeholders the user can utilize
     * to configure the custom messages:
     * {0}: The time when the log was added.
     * {1}: The type of the log (Trace, Debug , Information, etc)
     * {2}: A custom tag value provided by the user.
     * {3}: The log message.
     */
    LoggingService.prototype.setCustomMessage = function (type, message) {
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        this.messages[type] = message;
    };
    /**
     * Sets the minimum log level.
     */
    LoggingService.prototype.setMinimumLevel = function (type) {
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        this.minimumLevel = type;
    };
    /**
     * Logs the specified message.
     */
    LoggingService.prototype.log = function (message, type, tag) {
        if (type === void 0) { type = LogType.Trace; }
        if (tag === void 0) { tag = null; }
        if (type < 0 || type >= this.messages.length)
            throw new Error(LoggingService_1.typeNotRecognized);
        if (type < this.minimumLevel)
            return;
        var formattedMessage = paradigm_ui_web_shared_1.StringExtensions.format(this.messages[type], paradigm_ui_web_shared_1.DateExtensions.format(new Date(), "hh:mm:ss"), LogType[type], tag, message);
        var c = console;
        switch (type) {
            case LogType.Trace:
                c.trace(formattedMessage);
                break;
            case LogType.Debug:
                c.debug(formattedMessage);
                break;
            case LogType.Information:
                c.info(formattedMessage);
                break;
            case LogType.Warning:
                c.warn(formattedMessage);
                break;
            case LogType.Error:
                c.error(formattedMessage);
                break;
            case LogType.Critical:
                c.error(formattedMessage);
                break;
        }
    };
    LoggingService.prototype.trace = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Trace, tag);
    };
    LoggingService.prototype.debug = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Debug, tag);
    };
    LoggingService.prototype.information = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Information, tag);
    };
    LoggingService.prototype.warning = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Warning, tag);
    };
    LoggingService.prototype.error = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Error, tag);
    };
    LoggingService.prototype.critical = function (message, tag) {
        if (tag === void 0) { tag = null; }
        this.log(message, LogType.Critical, tag);
    };
    LoggingService.factory = function () {
        return new LoggingService_1();
    };
    LoggingService.typeNotRecognized = "The provided type is not recognized as a valida log type.";
    LoggingService = LoggingService_1 = tslib_1.__decorate([
        service_1.Service({ name: "$pd-loggingService" })
    ], LoggingService);
    return LoggingService;
    var LoggingService_1;
}(base_service_1.ServiceBase));
exports.LoggingService = LoggingService;
